Learn R Programming

OLStrajr (version 0.1.0)

print.cbc_lm: Print Method for 'cbc_lm' Objects

Description

Print method for 'cbc_lm' objects. Shows the call used to create the model, the mean coefficients, (optionally) the bootstrap mean coefficients, and the coefficients for each model.

Usage

# S3 method for cbc_lm
print(x, digits = max(3L, getOption("digits") - 3L), boot = FALSE, ...)

Value

An invisible 'cbc_lm' object.

Arguments

x

A 'cbc_lm' object.

digits

The number of significant digits to use when printing.

boot

Logical indicating whether or not to print the bootstrap mean coefficients.

...

Further arguments passed to or from other methods.

See Also

summary.cbc_lm, plot.cbc_lm