Learn R Programming

OLStrajr (version 0.1.0)

print.summary.cbc_lm: Print Method for 'summary.cbc_lm' Objects

Description

Print method for 'summary.cbc_lm' objects. Prints the call used to create the models, the mean coefficients, (optionally) the bootstrap mean coefficients, bootstrap standard errors, bootstrap confidence intervals, and the tidy and glance summaries for each model.

Usage

# S3 method for summary.cbc_lm
print(x, digits = max(3L, getOption("digits") - 3L), ...)

Value

An invisible 'summary.cbc_lm' object.

Arguments

x

A 'summary.cbc_lm' object.

digits

The number of significant digits to use when printing.

...

Further arguments passed to or from other methods.

See Also

print.cbc_lm, summary.cbc_lm