Summary method for 'cbc_lm' objects. Returns the mean coefficients, bootstrap mean coefficients, standard errors, and confidence intervals, as well as a summary of the models.
# S3 method for cbc_lm
summary(
object,
digits = max(3L, getOption("digits") - 3L),
boot = FALSE,
n_models = length(object$models),
...
)An object of class 'summary.cbc_lm', which includes the call, the mean coefficients, (optionally) the bootstrap mean coefficients, standard errors, confidence intervals, and a summary of the models.
A 'cbc_lm' object.
The number of significant digits to use when printing.
Logical indicating whether or not to include the bootstrap mean coefficients in the summary.
The number of models to include in the summary. Defaults to all models.
Further arguments passed to or from other methods.
print.cbc_lm, plot.cbc_lm