Print method for 'cbc_lm' objects. Shows the call used to create the model, the mean coefficients, (optionally) the bootstrap mean coefficients, and the coefficients for each model.
# S3 method for cbc_lm
print(x, digits = max(3L, getOption("digits") - 3L), boot = FALSE, ...)An invisible 'cbc_lm' object.
A 'cbc_lm' object.
The number of significant digits to use when printing.
Logical indicating whether or not to print the bootstrap mean coefficients.
Further arguments passed to or from other methods.
summary.cbc_lm, plot.cbc_lm